@@ -1,5 +1,5 @@
 package Lingua::YALI::Builder;
-# ABSTRACT: Constructs model for document identification.
+# ABSTRACT: Constructs language models for language identification.
 
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ use Moose::Util::TypeConstraints;
 use List::MoreUtils qw(uniq);
 use POSIX;
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 
 subtype 'PositiveInt',
@@ -19,17 +19,42 @@ subtype 'PositiveInt',
       message { "The number you provided, $_, was not a positive number" };
 
 
-has 'ngrams' => ( is => 'ro', isa => 'ArrayRef[PositiveInt]', required => 1 );
-has '_max_ngram' => ( is => 'rw', isa => 'Int' );
-has '_dict' => ( is => 'rw', isa => 'HashRef' );
+# list of all n-gram sizes that will be used during training
+has 'ngrams' => (
+    is => 'ro',
+    isa => 'ArrayRef[PositiveInt]',
+    required => 1
+    );
+
+# the greatest n-gram size
+# i.e. ngrams = [1, 2, 3]; _max_ngram = 3
+has '_max_ngram' => (
+    is => 'rw',
+    isa => 'Int'
+    );
+
+# hash of all n-grams
+# After procissing string 'ab' and n-grams set to [ 1, 2]:
+# _dict => { 1 => { 'a' => 1, 'b' => 1}; 2 => { 'ab' => 1 } }
+has '_dict' => (
+    is => 'rw',
+    isa => 'HashRef'
+    );
+
 
 sub BUILD
 {
     my $self = shift;
+
+    # keep only unique n-gram sizes
     my @unique = uniq( @{$self->{ngrams}} );
     my @sorted = sort { $a <=> $b } @unique;
     $self->{ngrams} = \@sorted;
-    $self->{_max_ngram} = $sorted[$#sorted];
+
+    # select the greatest n-gram
+    $self->{_max_ngram} = $sorted[-1];
+
+    return;
 }
 
 
@@ -51,6 +76,8 @@ sub get_max_ngram
 sub train_file
 {
     my ( $self, $file ) = @_;
+
+    # parameter check
     if ( ! defined($file) ) {
         return;
     }
@@ -65,6 +92,7 @@ sub train_string
 {
     my ( $self, $string ) = @_;
 
+    # parameter check
     if ( ! defined($string) ) {
         return;
     }
@@ -78,12 +106,14 @@ sub train_string
     return $result;
 }
 
+
 sub train_handle
 {
     my ($self, $fh) = @_;
 
 #    print STDERR "\nX\n" . (ref $fh) . "\nX\n";
 
+    # parameter check
     if ( ! defined($fh) ) {
         return;
     } elsif ( ref $fh ne "GLOB" ) {
@@ -116,7 +146,7 @@ sub train_handle
 
             my $act_length = bytes::length($_);
             $total_length += $act_length;
-                    
+
             for my $i (0 .. $act_length - $self->{_max_ngram}) {
                 $sub = substr($_, $i, $self->{_max_ngram});
                 for my $j (@ngrams) {
@@ -140,6 +170,7 @@ sub store
 {
     my ($self, $file, $ngram, $count) = @_;
 
+    # parameter check
     if ( ! defined($file) ) {
         croak("parametr file has to be specified");
     }
@@ -164,25 +195,28 @@ sub store
         croak("At least one n-gram has to be saved. Count was set to: $count");
     }
 
+    if ( ! defined($self->{_dict}->{$self->get_max_ngram()}) ) {
+        croak("No training data was used.");
+    }
+
+    # open file
     open(my $fhModel, ">:gzip:bytes", $file) or croak($!);
 
+    # prints out n-gram size
     print $fhModel $ngram . "\n";
 
+    # store n-grams
     my $i = 0;
-        
-    {
-        no warnings;
-
-        for my $k (sort { $self->{_dict}->{$ngram}{$b} <=> $self->{_dict}->{$ngram}{$a} } keys %{$self->{_dict}->{$ngram}}) {
-            print $fhModel "$k\t$self->{_dict}->{$ngram}{$k}\n";
-            if ( ++$i > $count ) {
-                last;
-            }
+    for my $k (sort { $self->{_dict}->{$ngram}{$b} <=> $self->{_dict}->{$ngram}{$a} } keys %{$self->{_dict}->{$ngram}}) {
+        print $fhModel "$k\t$self->{_dict}->{$ngram}{$k}\n";
+        if ( ++$i > $count ) {
+            last;
         }
     }
 
+
     close($fhModel);
-    
+
     return ($i - 1);
 }
 
@@ -194,25 +228,30 @@ __END__
 
 =head1 NAME
 
-Lingua::YALI::Builder - Constructs model for document identification.
+Lingua::YALI::Builder - Constructs language models for language identification.
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
 This modul creates models for L<Lingua::YALI::Identifier|Lingua::YALI::Identifier>.
 
+If your texts are from specific domain you can achive better
+results when your models will be trained on texts from the same domain.
+
 Creating bigram and trigram models from a string.
 
     use Lingua::YALI::Builder;
     my $builder = Lingua::YALI::Builder->new(ngrams=>[2, 3]);
     $builder->train_string("aaaaa aaaa aaa aaa aaa aaaaa aa");
+    $builder->train_string("aa aaaaaa aa aaaaa aaaaaa aaaaa");
     $builder->store("model_a.2_4.gz", 2, 4);
     $builder->store("model_a.2_all.gz", 2);
     $builder->store("model_a.3_all.gz", 3);
-    $builder->store("model_a.4_all.gz", 4); // croaks
+    $builder->store("model_a.4_all.gz", 4);
+    # croaks because 4-grams were not trained
 
 More examples is presented in L<Lingua::YALI::Examples|Lingua::YALI::Examples>.
 
@@ -222,7 +261,7 @@ More examples is presented in L<Lingua::YALI::Examples|Lingua::YALI::Examples>.
 
     BUILD()
 
-Constructs C<Builder>. It also removes duplicities from C<ngrams>.
+Constructs C<Builder>.
 
     my $builder = Lingua::YALI::Builder->new(ngrams=>[2, 3, 4]);
 
@@ -234,8 +273,8 @@ Returns all n-grams that will be used during training.
 
     my $builder = Lingua::YALI::Builder->new(ngrams=>[2, 3, 4, 2, 3]);
     my $ngrams = $builder->get_ngrams();
-    print join(", ", @$ngras) . "\n";
-    // prints out 2, 3, 4
+    print join(", ", @$ngrams) . "\n";
+    # prints out 2, 3, 4
 
 =head2 get_max_ngram
 
@@ -245,13 +284,13 @@ Returns the highest n-gram size that will be used during training.
 
     my $builder = Lingua::YALI::Builder->new(ngrams=>[2, 3, 4]);
     print $builder->get_max_ngram() . "\n";
-    // prints out 4
+    # prints out 4
 
 =head2 train_file
 
     my $used_bytes = $builder->train_file($file)
 
-Trains classifier on file C<$file> and returns the amount of bytes used for trainig. 
+Uses file C<$file> for training and returns the amount of bytes used.
 
 =over
 
@@ -269,7 +308,7 @@ For more details look at method L</train_handle>.
 
     my $used_bytes = $builder->train_string($string)
 
-Trains classifier on string C<$string> and returns the amount of bytes used for trainig. 
+Uses string C<$string> for training and returns the amount of bytes used.
 
 =over
 
@@ -285,7 +324,7 @@ For more details look at method L</train_handle>.
 
     my $used_bytes = $builder->train_handle($fh)
 
-Trains classifier on file handle C<$fh> and returns the amount of bytes used for trainig. 
+Uses file handle C<$fh> for training and returns the amount of bytes used.
 
 =over
 
@@ -301,14 +340,14 @@ Trains classifier on file handle C<$fh> and returns the amount of bytes used for
 
     my $stored_count = $builder->store($file, $ngram, $count)
 
-Stores trained model with at most C<$count> C<$ngram>-grams to file C<$file>. 
+Stores trained model with at most C<$count> C<$ngram>-grams to file C<$file>.
 If count is not specified all C<$ngram>-grams are stored.
 
 =over
 
-=item * It croaks if incorrect parameters are passed.
+=item * It croaks if incorrect parameters are passed or it was not trained.
 
-=item * It returns the amount of n-grams stored.
+=item * It returns the amount of stored n-grams.
 
 =back
 
@@ -316,7 +355,9 @@ If count is not specified all C<$ngram>-grams are stored.
 
 =over
 
-=item * Identifier for these models is L<Lingua::YALI::Identifier|Lingua::YALI::Identifier>.
+=item * Trained models are suitable for L<Lingua::YALI::Identifier|Lingua::YALI::Identifier>.
+
+=item * There is also command line tool L<yali-builder|Lingua::YALI::yali-builder> with similar functionality.
 
 =item * Source codes are available at L<https://github.com/martin-majlis/YALI>.
 
