@@ -8,7 +8,7 @@ use File::Glob;
 use Carp;
 use Moose;
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 extends 'Lingua::YALI::Identifier';
 
@@ -28,6 +28,7 @@ sub add_language
         $self->get_available_languages();
     }
 
+    # register languages
     my $added_languages = 0;
     for my $lang (@languages) {
         if ( ! defined($self->{_language_model}->{$lang}) ) {
@@ -39,6 +40,7 @@ sub add_language
     return $added_languages;
 }
 
+
 sub remove_language
 {
     my ($self, @languages) = @_;
@@ -48,6 +50,7 @@ sub remove_language
         $self->get_available_languages();
     }
 
+    # remove languages
     my $removed_languages = 0;
     for my $lang (@languages) {
         if ( ! defined($self->{_language_model}->{$lang}) ) {
@@ -70,8 +73,8 @@ sub get_languages
 sub get_available_languages
 {
     my $self = shift;
+    
     # Get a module's shared files directory
-
     if ( ! defined($self->_languages) ) {
 
         my $dir = File::ShareDir::dist_dir('Lingua-YALI');
@@ -82,7 +85,7 @@ sub get_available_languages
             my $language = $file;
             $language =~ s/\Q$dir\E.//;
             $language =~ s/.yali.gz//;
-            
+
             push(@languages, $language);
             $self->{_language_model}->{$language} = $file;
         }
@@ -112,22 +115,22 @@ Lingua::YALI::LanguageIdentifier - Module for language identification.
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
 This modul is for language identification and can identify 122 languages.
 
     use Lingua::YALI::LanguageIdentifier;
-    
-    // create identifier and register languages
+
+    # create identifier and register languages
     my $identifier = Lingua::YALI::LanguageIdentifier->new();
     $identifier->add_language("ces", "eng")
-    
-    // identify string
+
+    # identify string
     my $result = $identifier->identify_string("CPAN, the Comprehensive Perl Archive Network, is an archive of modules written in Perl.");
     print "The most probable language is " . $result->[0]->[0] . ".\n";
-    // prints out The most probable language is eng.    
+    # prints out The most probable language is eng.
 
 More examples is presented in L<Lingua::YALI::Examples|Lingua::YALI::Examples>.
 
@@ -137,31 +140,31 @@ More examples is presented in L<Lingua::YALI::Examples|Lingua::YALI::Examples>.
 
     my $added_languages = $identifier->add_languages(@languages)
 
-Registres new languages C<@languages> for identification and returns
-the amount of newly added languages. Languages are identified by their 
+Registers new languages C<@languages> for identification and returns
+the amount of newly added languages. Languages are identified by their
 ISO 639-3 code.
 
 It croaks when unsupported language is used.
 
     print $identifier->add_languages("ces", "deu", "eng") . "\n";
-    // prints out 3
+    # prints out 3
     print $identifier->add_languages("ces", "slk") . "\n";
-    // prints out 1
+    # prints out 1
 
 =head2 remove_language
 
     my $removed_languages = $identifier->remove_languages(@languages)
 
-Remove languages C<@languages> for identification and returns the amount
-of removed languages.
+Remove languages C<@languages> and returns the amount of removed languages.
 
 It croaks when unsupported language is used.
 
-    $identifier->add_languages("ces", "deu", "eng")
+    print $identifier->add_languages("ces", "deu", "eng")
+    # prints out 3
     print $identifier->remove_languages("ces", "slk") . "\n";
-    // prints out 1
+    # prints out 1
     print $identifier->remove_languages("ces", "slk") . "\n";
-    // prints out 0
+    # prints out 0
 
 =head2 get_languages
 
@@ -199,8 +202,6 @@ Identifies language for handle C<$fh>.
 
 For more details look at method L<Lingua::YALI::Identifier/identify_handle>.
 
-=encoding utf8
-
 =head1 LANGUAGES
 
 More details about supported languages may be found at L<http://ufal.mff.cuni.cz/~majlis/w2c/download.html>.
@@ -457,7 +458,9 @@ More details about supported languages may be found at L<http://ufal.mff.cuni.cz
 
 =over
 
-=item * General version for this identifier is L<Lingua::YALI::Identifier|Lingua::YALI::Identifier>.
+=item * Identifier for own models is L<Lingua::YALI::Identifier|Lingua::YALI::Identifier>.
+
+=item * There is also command line tool L<yali-language-identifier|Lingua::YALI::yali-language-identifier> with similar functionality.
 
 =item * Source codes are available at L<https://github.com/martin-majlis/YALI>.
 
